@@ -81,7 +81,6 @@ struct _GnomePilotDruidPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
-	GtkWidget *pilot_sync_type;
 };
 
 static void class_init (GnomePilotDruidClass *klass);
@@ -165,7 +164,7 @@ init (GnomePilotDruid *gpd)
 	priv->device = g_new0 (GPilotDevice,1);
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", NULL);
+	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", NULL, NULL);
 	if (!priv->xml) {
 		g_message ("gnome-pilot-druid init(): Could not load the Glade XML file!");
 		goto error;
@@ -180,9 +179,6 @@ init (GnomePilotDruid *gpd)
 	fill_widgets (gpd);
 	init_widgets (gpd);
 
-	priv->state->pilots = g_list_append (priv->state->pilots, priv->pilot);
-	priv->state->devices = g_list_append (priv->state->devices, priv->device);
-
  error:
 }
 
@@ -247,7 +243,6 @@ get_widgets (GnomePilotDruid *gpd)
 
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
-	priv->pilot_sync_type = GW ("sync_type_menu");
 	
 #undef GW
 
@@ -272,8 +267,7 @@ get_widgets (GnomePilotDruid *gpd)
 		&& priv->sync_label_vbox
 		&& priv->sync_label
 		&& priv->pilot_name
-		&& priv->pilot_basedir
-		&& priv->pilot_sync_type);
+		&& priv->pilot_basedir);
 }
 
 static void
@@ -295,7 +289,6 @@ map_widgets (GnomePilotDruid *gpd)
 	gtk_object_set_data (GTK_OBJECT (gpd), "pilotid", priv->pilot_id);
 	gtk_object_set_data (GTK_OBJECT (gpd), "pilotname", priv->pilot_name);
 	gtk_object_set_data (GTK_OBJECT (gpd), "basedir", priv->pilot_basedir);
-	gtk_object_set_data (GTK_OBJECT (gpd), "sync_menu", priv->pilot_sync_type);
 }
 
 static void 
@@ -313,19 +306,19 @@ init_widgets (GnomePilotDruid *gpd)
 			    GTK_SIGNAL_FUNC (gpd_canceled), gpd);
 
 	/* Page signals */
-	gtk_signal_connect (GTK_OBJECT (priv->page_cradle), "prepare",
-			    GTK_SIGNAL_FUNC (gpd_cradle_page_prepare), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_cradle), "prepare",
+				G_CALLBACK (gpd_cradle_page_prepare), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_sync), "prepare",
-			    GTK_SIGNAL_FUNC (gpd_sync_page_prepare), gpd);
-	gtk_signal_connect (GTK_OBJECT (priv->page_sync),"back",
-			   GTK_SIGNAL_FUNC (gpd_sync_page_back), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_sync), "prepare",
+				G_CALLBACK (gpd_sync_page_prepare), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_sync),"back",
+				G_CALLBACK (gpd_sync_page_back), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_pilot_two), "next",
-			    GTK_SIGNAL_FUNC (gpd_pilot_page_two_next), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_pilot_two), "next",
+				G_CALLBACK (gpd_pilot_page_two_next), gpd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->page_finish), "finish",
-			    GTK_SIGNAL_FUNC (gpd_finish_page_finished), gpd);
+	g_signal_connect_after (G_OBJECT (priv->page_finish), "finish",
+				G_CALLBACK (gpd_finish_page_finished), gpd);
 
 	/* Other widget signals */
 	gtk_signal_connect (GTK_OBJECT (priv->device_name),"changed",
@@ -379,8 +372,6 @@ fill_widgets (GnomePilotDruid *gpd)
 
 	g_free (str);
 	g_free (str2);
-
-	fill_synctype_menu (GTK_OPTION_MENU (priv->pilot_sync_type), GnomePilotConduitSyncTypeNotSet);
 }
 
 gboolean
@@ -406,14 +397,16 @@ static gboolean
 cancel_dialog (GnomePilotDruid *gpd)
 {
 	GnomePilotDruidPrivate *priv;
-	gint btn;
+	GtkWidget *dlg;
 	
 	priv = gpd->priv;
-	
-	btn = yes_no_dialog (_("Setup did not complete and settings will not\n"
-				  "be saved. Are you sure you want to quit?"));
 
-	if (btn == 1) {
+	dlg = gtk_message_dialog_new (GTK_WINDOW (priv->druid_window), GTK_DIALOG_DESTROY_WITH_PARENT, 
+				      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+				      _("Setup did not complete and settings will not\n"
+					"be saved. Are you sure you want to quit?"));
+
+	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_YES) {
 		if (priv->handle > 0) {
 			gnome_pilot_client_remove_request (priv->gpc, priv->handle);
 			priv->handle =-1;
@@ -421,9 +414,15 @@ cancel_dialog (GnomePilotDruid *gpd)
 		save_config_and_restart (priv->gpc, priv->orig_state);
 		freePilotState (priv->state);
 		priv->state = dupPilotState (priv->orig_state);
+	
+		gtk_widget_destroy (dlg);
+	
+		return TRUE;
 	}
 
-	return btn ? TRUE : FALSE;
+	gtk_widget_destroy (dlg);
+
+	return FALSE;
 }
 
 static gboolean
@@ -468,7 +467,7 @@ gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data
 	gboolean ready;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -483,6 +482,8 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 	priv = gpd->priv;
 
 	read_device_config (GTK_OBJECT (gpd), priv->device);
+	if (priv->state->devices == NULL)
+		priv->state->devices = g_list_append (priv->state->devices, priv->device);
 
 	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active) {
 		/* do send_to_pilot */
@@ -523,12 +524,12 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
         g_free (text);
 
 	if (priv->handle <= 0) {
-		error_dialog (_("Failed sending request to gpilotd"));
+		error_dialog (GTK_WINDOW (priv->druid_window), _("Failed sending request to gpilotd"));
 		return;
 	}
 
 	/* disable NEXT until we've synced */
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE, FALSE);
 }
 
 static gboolean
@@ -542,6 +543,7 @@ gpd_sync_page_back (GnomeDruidPage *druidpage, gpointer arg1, gpointer user_data
 	if (priv->handle>0) {
 		gnome_pilot_client_remove_request (priv->gpc, priv->handle);  
 		priv->handle =-1;
+		save_config_and_restart (priv->gpc, priv->orig_state);
 	}
 	return FALSE;
 }
@@ -566,6 +568,7 @@ gpd_finish_page_finished (GnomeDruidPage *druidpage, gpointer arg1, gpointer use
 	priv = gpd->priv;
 	
 	read_pilot_config (GTK_OBJECT (gpd), priv->pilot);
+	priv->state->pilots = g_list_append (priv->state->pilots, priv->pilot);
 	
 	save_config_and_restart (priv->gpc, priv->state);
 	
@@ -584,7 +587,7 @@ gpd_device_info_check (GtkEditable *editable, gpointer user_data)
 	priv = gpd->priv;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -599,7 +602,7 @@ gpd_pilot_info_check (GtkEditable *editable, gpointer user_data)
 	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -615,7 +618,7 @@ gpd_pilot_info_button (GtkToggleButton *toggle, gpointer user_data)
 	if (toggle->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void 
@@ -629,7 +632,7 @@ gpd_request_completed (GnomePilotClient* client, const gchar *id, gint handle, g
 	if (handle != priv->handle)
 		return;
 	
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
 }
 
 static void 
@@ -662,7 +665,7 @@ gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_id), buf);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
 
 	g_free (text);
 	priv->handle = -1;
@@ -677,7 +680,7 @@ gpd_destroy (GtkObject *object)
 	priv = gpd->priv;
 
 	gtk_widget_destroy (priv->druid_window);
-	gtk_object_unref (GTK_OBJECT (priv->xml));
+	g_object_unref (priv->xml);
 
 	gtk_signal_disconnect_by_data (GTK_OBJECT (priv->gpc), object);
 
